@@ -23,6 +23,7 @@ from .GPGSigVerifier import *
 
 class DebianSigVerifier(GPGSigVerifier):
     _dpkg_ring = '/etc/dpkg/local-keyring.gpg'
+    keyrings_r_ok = []
 
     def __init__(self, keyrings=None, extra_keyrings=None):
         if not keyrings:
@@ -31,6 +32,9 @@ class DebianSigVerifier(GPGSigVerifier):
             keyrings.append(self._dpkg_ring)
         if extra_keyrings:
             keyrings.extend(extra_keyrings)
-        GPGSigVerifier.__init__(self, keyrings)
+        for keyring in keyrings:
+            if os.access(keyring, os.R_OK):
+                self.keyrings_r_ok.append(keyring)
+        GPGSigVerifier.__init__(self, self.keyrings_r_ok)
 
 # vim:ts=4:sw=4:et:
